# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-01-18 09:19
from __future__ import unicode_literals

import django.core.files.storage
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_exam', '0010_auto_20180118_1534'),
    ]

    operations = [
        migrations.CreateModel(
            name='GradeCertField',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=180)),
                ('field', models.CharField(max_length=180)),
                ('width', models.IntegerField()),
                ('color', models.CharField(max_length=7)),
            ],
            options={
                'ordering': ['id'],
                'db_table': 'bee_django_exam_grade_cert_field',
            },
        ),
        migrations.AlterField(
            model_name='grade',
            name='cert_image',
            field=models.ImageField(blank=True, null=True, storage=django.core.files.storage.FileSystemStorage(location=b'media/exam/cert'), upload_to=b'', verbose_name='\u8bc1\u4e66\u56fe\u7247'),
        ),
        migrations.AddField(
            model_name='gradecertfield',
            name='grade',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_exam.Grade'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-01-12 10:21
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_exam', '0002_auto_20180112_1812'),
    ]

    operations = [
        migrations.AlterField(
            model_name='notice',
            name='title',
            field=models.CharField(max_length=180, verbose_name='\u987b\u77e5\u6807\u9898'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-01-18 07:34
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_exam', '0009_auto_20180118_1520'),
    ]

    operations = [
        migrations.AlterField(
            model_name='userexamrecord',
            name='passed_date',
            field=models.CharField(blank=True, max_length=180, null=True, verbose_name='\u901a\u8fc7\u65e5\u671f'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-01-14 06:17
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_exam', '0004_auto_20180114_1415'),
    ]

    operations = [
        migrations.AlterField(
            model_name='userexamrecord',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, null=True),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-01-20 08:05
from __future__ import unicode_literals

import django.core.files.storage
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_exam', '0015_auto_20180119_1523'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='gradecertfield',
            name='color',
        ),
        migrations.RemoveField(
            model_name='gradecertfield',
            name='width',
        ),
        migrations.AddField(
            model_name='gradecertfield',
            name='font_color',
            field=models.CharField(default='#FFFFFF', max_length=7, verbose_name='\u5b57\u4f53\u989c\u8272'),
        ),
        migrations.AddField(
            model_name='gradecertfield',
            name='font_size',
            field=models.IntegerField(default=12, max_length=3, verbose_name='\u5b57\u4f53\u5927\u5c0f'),
        ),
        migrations.AddField(
            model_name='gradecertfield',
            name='text_align',
            field=models.CharField(default='left', max_length=180, verbose_name='\u6587\u5b57\u5bf9\u9f50'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='gradecertfield',
            name='text_bg_color',
            field=models.CharField(default='#FFFFFF', max_length=7, verbose_name='\u6587\u5b57\u533a\u57df\u80cc\u666f\u989c\u8272'),
        ),
        migrations.AddField(
            model_name='gradecertfield',
            name='text_post_x',
            field=models.IntegerField(default=0, verbose_name='\u6587\u5b57\u533a\u57df\u5de6\u4e0a\u89d2\u6a2a\u5750\u6807'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='gradecertfield',
            name='text_post_y',
            field=models.IntegerField(default=0, verbose_name='\u6587\u5b57\u533a\u57df\u5de6\u4e0a\u89d2\u7eb5\u5750\u6807'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='gradecertfield',
            name='text_width',
            field=models.IntegerField(default=100, verbose_name='\u6587\u5b57\u533a\u57df\u5bbd\u5ea6'),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='grade',
            name='cert_image',
            field=models.ImageField(blank=True, null=True, storage=django.core.files.storage.FileSystemStorage(base_url='/media/exam/cert', location=b'media/exam/cert'), upload_to=b'', verbose_name='\u8bc1\u4e66\u56fe\u7247'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-11-17 06:16
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_exam', '0025_userstartexam'),
    ]

    operations = [
        migrations.AlterField(
            model_name='userexamrecord',
            name='status',
            field=models.IntegerField(blank=True, choices=[(-1, '\u672a\u62a5\u540d'), (-2, '\u5df2\u62a5\u540d'), (1, '\u901a\u8fc7'), (2, '\u672a\u901a\u8fc7'), (3, '\u5173\u95ed')], default=-1, null=True, verbose_name='\u72b6\u6001'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-01-19 07:22
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_exam', '0013_grade_cert_image'),
    ]

    operations = [
        migrations.AlterField(
            model_name='grade',
            name='cert_image',
            field=models.ImageField(blank=True, null=True, upload_to='static', verbose_name='\u8bc1\u4e66\u56fe\u7247'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-01-14 07:58
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_exam', '0007_userexamrecord_passed_date'),
    ]

    operations = [
        migrations.AlterField(
            model_name='userexamrecord',
            name='is_passed',
            field=models.BooleanField(default=False, verbose_name='\u662f\u5426\u901a\u8fc7'),
        ),
    ]
